/*
    ChibiOS - Copyright (C) 2006..2016 Giovanni Di Sirio

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

#include "ch.h"
#include "hal.h"

#include "chprintf.h"

#include "lsm303dlhc.h"


/*===========================================================================*/
/* LSM303DLHC related.                                                       */
/*===========================================================================*/

/* LSM303DLHC Driver: This object represent an LSM303DLHC instance */
static LSM303DLHCDriver LSM303DLHCD1;

static float cookeddata[LSM303DLHC_ACC_NUMBER_OF_AXES];


static const I2CConfig i2ccfg = {
  STM32_TIMINGR_PRESC(15U) |
  STM32_TIMINGR_SCLDEL(4U) | STM32_TIMINGR_SDADEL(2U) |
  STM32_TIMINGR_SCLH(15U)  | STM32_TIMINGR_SCLL(21U),
  0,
  0
};

static const LSM303DLHCAccConfig lsm303dlhcacccfg = {
  NULL,                             /* Use default sensitivity.*/
  NULL,                             /* Use default bias.*/
  LSM303DLHC_ACC_FS_4G,             /* Full scale value 2g.*/
  LSM303DLHC_ACC_ODR_100Hz,         /* Output data rate 100 Hz.*/
};



static const LSM303DLHCConfig lsm303dlhccfg = {
  &I2CD1,
  &i2ccfg,
  &lsm303dlhcacccfg
};

/*===========================================================================*/
/* Generic code.                                                             */
/*===========================================================================*/



/*
 * Application entry point.
 */
int main(void) {

  /*
   * System initializations.
   * - HAL initialization, this also initializes the configured device drivers
   *   and performs the board-specific initializations.
   * - Kernel initialization, the main() function becomes a thread and the
   *   RTOS is active.
   */
  halInit();
  chSysInit();

  /*
   * Creates the blinker thread.
   */

  /*
   * LSM303DLHC Object Initialization
   */
  lsm303dlhcObjectInit(&LSM303DLHCD1);

  /*
   * Activates the LSM303DLHC driver.
   */
  lsm303dlhcStart(&LSM303DLHCD1, &lsm303dlhccfg);

  /*
   * Normal main() thread activity, spawning shells.
   */
  while (true) {
      sensorReadCooked(&LSM303DLHCD1, cookeddata);

      for(unsigned int i=0; i<3; i++){
        cookeddata[i]=cookeddata[i]/1000;
      }
      if(cookeddata[0]<0){
        palSetLine(LINE_LED10_RED);
        palClearLine(LINE_LED7_GREEN);
      }
      if(cookeddata[1]<0){
        palClearLine(LINE_LED10_RED);
        palSetLine(LINE_LED7_GREEN);
      }

      if(cookeddata[2]>1.5 || cookeddata[2]<-1.5){
        palSetLine(LINE_LED8_ORANGE);
      }else{
        palClearLine(LINE_LED8_ORANGE);
      }


      chThdSleepMilliseconds(200);
      palClearLine(LINE_LED9_BLUE);

  }
  lsm303dlhcStop(&LSM303DLHCD1);
}
